@@ -61,11 +61,18 @@ class ImagePostModelAnalysis:
         if "class" not in self.images_data.problem_type:
             return None
         try:
-            cm = confusion_matrix(self.eval_labels.cpu().numpy(), self.eval_predictions.cpu().numpy())
-        except:
             cm = confusion_matrix(self.eval_labels, self.eval_predictions)
+            print("wow!")
+        except:
+            try:
+                self.diamond_collector["aaa"] = self.eval_labels
+                self.diamond_collector["aaa"] = self.eval_predictions
+                cm = confusion_matrix(self.eval_labels.cpu().numpy(), self.eval_predictions.cpu().numpy())
+                print("wow!!")
+            except:
+                cm = confusion_matrix(self.eval_labels, self.eval_predictions.cpu().numpy())
+                print("wow!!!")
         self.diamond_collector["confusion matrix"] = cm
-
         # Create confusion matrix plot
         if plot:
             fig, ax = plt.subplots(figsize=(8, 8))
